@@ -20,13 +20,9 @@ class TestopsConfig(BaseModel):
         self.batch = BatchConfig()
         self.plan = PlanConfig()
         self.defect = False
-        self.use_v2 = True
 
     def set_project(self, project: str):
         self.project = project
 
     def set_defect(self, defect):
         self.defect = QaseUtils.parse_bool(defect)
-
-    def set_use_v2(self, use_v2):
-        self.use_v2 = QaseUtils.parse_bool(use_v2)
